@@ -1,12 +1,12 @@
-compute_variance <- function(sample_size, effect_size, es_type, con_table){
+compute_variance <- function(study_size, effect_size, es_type, con_table){
 
   if(es_type == "d"){
 
-    return(round(((sample_size+sample_size)/((sample_size)*(sample_size))) + ((effect_size^2)/(2*(sample_size+sample_size))),5))
+    return(round(((study_size/2+study_size/2)/((study_size/2)*(study_size/2))) + ((effect_size^2)/(2*(study_size/2+study_size/2))),5))
 
     } else if (es_type == "r"){
 
-      return(1/(sample_size-3))
+      return(1/(study_size-3))
 
       }else if (es_type == "or"){
         con_table <- data.frame(a = con_table[1],
