@@ -4,8 +4,9 @@ summary.homogen_power <- function(object,...) {
 
   cat("\n Power Analysis for Test of Homogeneity in Meta-analysis \n\n")
 
+  cat(" Effect Size Metric:               ", object$es_type, "\n")
   cat(" Expected Effect Size:             ", object$effect_size, "\n")
-  cat(" Expected Sample Size (per group): ", object$sample_size, "\n")
+  cat(" Expected Study Size:              ", object$study_size, "\n")
   cat(" Expected Number of Studies:       ", object$k, "\n\n")
 
   cat(" Estimated Power: Test of Homogeneity \n\n")
@@ -16,8 +17,6 @@ summary.homogen_power <- function(object,...) {
   cat(" Fixed-Effects Model (SD = 4)       ", object$homogen_power$fixed_power_sd4, "\n")
   cat(" Fixed-Effects Model (SD = 5)       ", object$homogen_power$fixed_power_sd5, "\n\n")
 
-  cat(" Random-Effects Model (i2 =   0% ): ", object$homogen_power$random_power_0, "\n")
-  cat(" Random-Effects Model (i2 =  25% ): ", object$homogen_power$random_power_s, "\n")
-  cat(" Random-Effects Model (i2 =  50% ): ", object$homogen_power$random_power_m, "\n")
-  cat(" Random-Effects Model (i2 =  75% ): ", object$homogen_power$random_power_l, "\n\n")
+  cat(" Random-Effects Model (i2 = ",round(object$i2*100,2), "%):    ", object$homogen_power$random_power, "\n", sep = "")
+
 }
